* migstat05_stata.zip: migstat05.do .

clear
capture log close
set more off
set memory 800m
set dp comma
set linesize 250


* Wechseln in das Arbeitsverzeichnis
cd <Arbeitsverzeichnis>

log using migstat05.log, text replace

/* ============================================================================
   Stata-PROGRAMM ZUR TYPISIERUNG DES MIGRATIONSSTATUS IM MIKROZENSUS 2005
                                                                      
Programmautor/en:                                                    
   SAS-Originalprogramm: Gunter Brueckner (Statistisches Bundesamt; 
      Referat F 204 Migration und Integration, Wohnen)
   Anpassungen an Scientific Use File Mikrozensus 2005: Delia Jaeger
            Bernhard Schimpl-Neimanns (GESIS, GML)

Programmzweck:
   Dieses Programm dient der Replikation des Migrationsstatus und der 
   Staatsangehoerigkeit zum Migrationsstatus im Scientific Use File (SUF) des 
   Mikrozensus 2005.                                   .
   Die Programme basieren auf den SAS-Programmen zum Original-Mikrozensus des 
   Statistischen Bundesamtes und wurden an Recodierungen des SUF angepasst.
   Bei der Replikation der Variablen Staatsangehoerigkeit zum Migrationsstatus
   (MIGS) ist zu beachten, dass aus Gruenden des Datenschutzes Angaben zur 
   zweiten Staatsangehoerigkeit nur rudimentaer vorhanden sind (s. u.). Die 
   Replikation ist deshalb nur mit Abweichungen moeglich.

Weiterfuehrende Programmbeschreibung:
   Jaeger, Delia und Bernhard Schimpl-Neimanns: Typisierung des 
      Migrationshintergrundes in den Mikrozensus Scientific-Use-Files 
      2005-2009. GESIS-Technical Report Nr. 2012/08. Mannheim: GESIS. URL: 
      http://www.gesis.org/fileadmin/upload/forschung/publikationen/
      gesis_reihen/gesis_methodenberichte/2012/TechnicalReport_2012-08.pdf

Download dieser Datei:
      http://www.gesis.org/missy/studie/klassifikationen/
      konzepte-und-definitionen/migrationshintergrund/migstat05_stata.zip 

Siehe auch Anhang 1: Personen mit Migrationshintergrund - Auf dem Weg zu 
      einer definitorischen Abgrenzung - S. 398-407 in: Statistisches 
      Bundesamt, 2011: Bevoelkerung mit Migrationshintergrund. Ergebnisse 
      des Mikrozensus 2009. Fachserie 1 Reihe 2.2. Wiesbaden. URL:
      https://www.destatis.de/DE/Publikationen/Thematisch/Bevoelkerung/
      MigrationIntegration/Migrationshintergrund2010220097004.pdf?__blob= 
      publicationFile; letzter Zugriff: 24.07.2012

Programmstruktur:
  0. Datenvorbereitung
  1. Grundtypisierung des Migationshintergrundes
  2. Identifikation von 3-Generationen-Haushalten
  3. Endtypisierung der Grosseltern
  4. Endtypisierung der Eltern
  5. Endtypisierung Befragte
  6. Umsetzung von Zeitreihenkompatibilitaet
  7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse

Programmstatus:
   Getestet mit Stata/MP 12.1 for Windows und Scientific Use File 
   Mikrozensus 2005, Version 3, Stand: Juli 2012
============================================================================ */


* ============================================================================
* 0. Datenvorbereitung

* Datenquelle: Scientific Use File Mikrozensus 2005, Version 3 vom 05.12.2007
* lokalen Dateinamen in < > eintragen
use EF1  EF3   EF4   EF5   EF12  EF30  EF31  EF44  EF46 EF47 ///
    EF49  EF50  EF51  EF52  EF53  EF54  EF55  EF349 EF350 EF351 ///
    EF352 EF353 EF354 EF355 EF356 EF357 EF358 EF359 EF360 ///
    EF361 EF362 EF363 EF364 EF365 EF366 EF367 EF368 EF369 ///
    EF370 EF371 EF372 EF373 EF374 EF382 EF663 EF732 EF952 ///
    using <mz2005.dta>, replace 

* Gross- => Kleinschreibung der Variablennamen
renpfix EF ef

* Codes in Value Label aufnehmen
numlabel _all, add mask("[#] ")

* Satznummer Ausgangsfile 
gen ID_O = _n
lab var ID_O "Satznummer Ausgangsfile mz2005.dta"

* Variablenauszug speichern
save mz2005_mig.dta, replace

* Ausgangssortierung.
sort ef1 ef3 ef4 ef12 ef5


* -----------------------------------------------------------------------------
* HARMONISIERUNG STAATSANGEHOERIGKEITEN
* Sicherung der Originalvariablen *_O
rename ef353 ef353_O
rename ef361 ef361_O
rename ef365 ef365_O
rename ef369 ef369_O
rename ef374 ef374_O
rename ef382 ef382_O

recode ef369_O (0=0) (23=1) (30=2) (4=3) (9 10 13 21 22 24 32 36 37=3) (26=4) ///
               (34=5) (3=6) (2 5 6 14 28 29 38 38=7) (40 41 41=8) ///
               (43 45 55=9) (47 48=10) (50 51 52=11), gen(ef369)
recode ef374_O (0=0) (23=1) (30 33 35=2) (4 9 10 13 21 22 32 36 37=3) (26=4) ///
               (34=5) (3 25=6) (2 14 29 38=7) (40 41 42=8) (43 45 55=9) ///
               (47 48 49=10) (50 51 52 53 54=11), gen(ef374)
recode ef353_O (0=0) (23=1) (30=2) (4 9 10 13 21 22 24 32 36 37=3) (26=4) ///
               (34=5) (3=6) (2 5 6 14 29 38 39=7) (40 41=8) (43 45 55=9) ///
               (47 48=10) (50 51 52=11), gen(ef353)
recode ef382_O (0=0) (23=1) (30=2) (37=3) (26=4) (34=5) (3=6) (5 6 38=7) ///
               (40=8) (55=9) (49=10) (54=11), gen(ef382)
recode ef361_O (0=0) (23=1) (30=2) (37=3) (26=4) (34=5) (3=6) (5 6 38=7) ///
               (40=8) (55=9) (49=10) (54=11), gen(ef361) 
recode ef365_O (0=0) (23=1) (30=2) (13 37=3) (26=4) (34=5) (3=6) (5 6 38=7) ///
               (40=8) (55=9) (49=10) (54=11), gen(ef365)

			   
label var ef369 "F100a 1. Staatsangehoerigkeit recodiert"
label var ef374 "F101b Staatsangehoerigk.: vor Einbuergerung recodiert"
label var ef353 "F106 1. ausl. Staatsangehoerigk.: Mutter recodiert"
label var ef382 "F109 Staatsangehoerigk.: Mutter, vor Einbuergerung recodiert"
label var ef361 "F113 1. ausl. Staatsangehoerigk.: Vater recodiert"
label var ef365 "F116 Staatsangehoerigk.: Vater, vor Einbuergerung recodiert"


label def migs /// Label fuer ef369 ef374 ef353 ef382 ef361 ef365 sa_erw migs migs2005
    0 "[0] Entfaellt (Deutsche(r) ohne weitere Staatsangehoerigkeit)" ///
    1 "[1] EU-25: PL Polen(23)" ///
    2 "[2] EU-25: SK, CZ, HU: Slowakei (30), Tschechische Republik(33), Ungarn(35)" ///
    3 "[3] EU-25: B, DK, EST, FIN, F,GR, IRL, I, LV, L, M, NL, A, P, S, E, GB, CY" ///
    4 "[4] EU Sonst: RUS: Russische Foederation(26)" ///
    5 "[5] EU Sonst: TR: Tuerkei(34)" ///
    6 "[6] EU Sonst: BG, RO: Bulgarien(03), Rumaenien(25)" ///
    7 "[7] EU Sonst: EU Sonst: BIH,SU, Y, IS, NDH, FL, N, CH, SB, MN" ///
    8 "[8] Afrika: Marokko(40), Sonstiges Nordafrika(41), Sonstiges Afrika(42)" ///
    9 "[9] Amerika, Uebrige Welt, Staatenlos: USA(43), Sonstiges Nordamerika(44), Mittelamerika und Karibik(45), Suedamerika(46), Uebrige Welt(55), Staatenlos(98)" ///
   10 "[10] Naher und Mittlerer Osten: Irak(47), Iran(48), Sonst ... (49)" ///
   11 "[11] Asien: Vietnam(50), Afghanistan(51), Sonst. Sued-/Suedostasien(52), China(53), Sonst. Ostasien(54)" ///
   99 "[99] Unbekannt"
   
   
/* Ausfuehrliche Labels:
[3] Belgien(1), Daenemark(4), Estland(7), Finnland(8), Frankreich(9), Griechenland(10), 
    Irland(11), Italien(13), Lettland(15), Litauen(17), Luxemburg(18), Malta(19), 
    Niederlande(21), Oesterreich(22, Portugal(24), Schweden(27), Slowenien(31), 
    Spanien(32), Vereinigtes Koenigreich(36), Zypern(37)
[7] Bosnien und Herzegowina(02), Ehemalige Sowjetunion(05), Ehemaliges 
    Jugoslawien(06), Island(12), Kroatien(14), Liechtenstein(16), Norwegen(20), 
    Schweiz(28), Serbien und Montenegro(29), Sonstiges Osteuropa(38), 
Sonstiges Europa(39) 
*/


format ef369 ef374 ef353 ef382 ef361 ef365 %2.0f

/* ----------------------------------------------------------------------------
Differenzierte Angaben zur 2. Staatsangehoerigkeit liegen nicht vor: 
EF370 F100a 2. Staatsangehoerigkeit
       1 "vorhanden"
       0 "Entfaellt (Deutscher, Auslaender mit nur einer Staatsangeh.)"
EF354 F106 2. ausl. Staatsangehoerigk.: Mutter
      1 "EU (...)"
      2 "Uebrige Welt, Staatenlos"
      0 "Entfaellt"
EF362 F113 2. ausl. Staatsangehoerigk.: Vater
      1 "vorhanden"
      0 "Entfaellt (Deutscher, Auslaender mit nur einer Staatsangeh.)"

Aus diesem Grund ist selbst nach Harmonisierung der obigen Variablen 
mit Abweichungen der Staatsangehoerigkeit zum Migrationsstatus (MIGS*)
zu den veroeffentlichten Verteilungen zu rechnen.
==> Im Folgenden werden wegen fehlender 2. Staatsangehoerigkeiten die
==> Zuweisungen zu Variablen SA2* deaktiviert
---------------------------------------------------------------------------- */

/* ======================================================================
1. Grundtypisierung des Migrationshintergrundes 

   Es werden zunaechst nur die Angaben der Person selbst zur Typisierung 
   verwendet. In den Jahren 2005 und 2009 werden die nicht im Haushalt 
   lebenden Eltern ebenfalls grundtypisiert. 
   Die erste Typisierung erfolgt nach Angaben zur Staatsangehoerigkeit 
   (deutsch / nicht-deutsch) und Geburtsland (Ausland / Inland).
*/

/* Ueberblick zu den nachfolgenden Zuweisungen: */
/* MIG: Migrationstypus
        1. Stelle: Migrationstyp: 
           1=vertrieben
           2=als Deutsche/r bzw. Spaetaussiedler zugewandert
           3=eingebuergert
           4=Auslaender/in
        2. Stelle: Generation:
           1=im Ausland geboren
           2=in Deutschland geboren

	  vorlaeufige Codes MIG:
	  11=Vertriebene vor 1950
          21=Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung);
          22=Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung);
          25=(Spaet-)Aussiedler (mit Einbuergerung);
          29=(Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr;
          31=zugewanderte/r eingebuergerte/r Auslaender/in;
          32=nicht zugewanderte/r eingebuergerte/r Auslaender/in;
          41=zugewanderte/r Auslaender/in;
          42=nicht zugewanderte/r Auslaender/in;
          77=uneindeutig ob deutsch, vertrieben oder Spaetaussiedler 
          99=fehlende/unvollstaendige Angaben 

SA: aktuelle Staatsangehoerigkeit
SA_erw: erweiterte aktuelle Staatsangehoerigkeit
             gewonnen aus SA1 - SA3 nach folgenden Regeln:
           0=deutsch (bei MIG=0, 11);
           =SA1 (bei Mig=41,42);
           =SA3 (bei Mig=21,25,29,31,32 und SA3<>.);
           =SA2 (bei MIG=21,25,29,31,32 und SA3=.und SA2<>.)
           =99 (bei MIG=21,25,29,31,32 und SA2=. und SA3=. oder bei MIG=77,99) 
SA_erw = 0   = deutsch (bei MIG=0, 11)                             
        = SA1 (bei Mig=41,42)                                       
        = SA3 (bei Mig=21,25,29,31,32 und SA3<>.)                   
        = SA2 (bei MIG=21,25,29,31,32 und SA3=. und SA2<>.)         
        = 99  (bei MIG=21,25,29,31,32 und SA2=. und SA3=. oder      
               bei MIG=77,99)                                       
          [Sysmis sind oben bezeichnet mit: "." ] 			*/	   

	
* Geburtsjahr und Familienstand der Person
generate gebj=ef47
label var gebj "Geburtsjahr"

generate brdborn = ef366
label var brdborn "Geburtsland: BRD (ef366)"
label def brdborn 1 "[1] Ja, hier geboren" 8 "[8] Nein, zugezogen", add modify
label val brdborn brdborn

recode brdborn (1=0) (8=1), gen(zuzug)
label var zuzug "Zuzug ex BRDBorn, ef366"
label def zuzug 0 "[0] kein Zuzug" 1 "[1] foreign born" 2 "[2] Zuzug nach 6+ Mo im Ausland:= in D geboren", add modify
label val zuzug zuzug
recode ef367 (1949=1949) (9999=9) (0=0), gen(jzuzug) copyrest
label def jzuzug 1949 "Zuzug vor 1950" 9 "[9] o.A. zum Zuzugsjahr"  0 "[0] kein Zuzugsjahr sinnvoll", add modify
label val jzuzug jzuzug
replace zuzug=2  if brdborn==1 & jzuzug>9
* replace jzuzug=9 if brdborn==8 & (ef367==0 | ef367==9999)
replace jzuzug=9 if brdborn==8 & jzuzug<10

* Initialisierung
gen mig=.     // Migrationsstatus
gen ausl=.    // Auslaender
gen sadopp=.  // Doppelte Staatsangehoerigkeit
gen sa=.      // Aktuelle Staatsangehoerigkeit
gen sa1=.     // Aktuelle (erste) Staatsangehoerigkeit (EF368-EF370
gen sa2=.     // Aktuelle (zweite) Staatsangehoerigkeit (EF368-EF370)
gen sa3=.     // Staatsangehoerigkeit vor Einbuergerung 
gen eingeb=.  // Eingebuergert
gen jeinb=.   // Jahr der Einbuergerung
gen sa_erw=.  // Erweiterte aktuelle Staatsangehoerigkeit

* nur deutsche Staatsangehoerigkeit (SA)
replace ausl=0   if ef368==1
replace sadopp=0 if ef368==1
replace sa1=0    if ef368==1
replace sa2=.    if ef368==1
  
* deutsche und auslaendische SA
replace ausl=0    if ef368==2
replace sadopp=1  if ef368==2 
replace sa1=0     if ef368==2
replace sa2=ef369 if ef368==2

* nur auslaendische SAs
replace ausl=1    if ef368==8
replace sa1=ef369 if ef368==8
replace sadopp=0  if ef368==8 & ef370==0 // ef370=0: Ausl. mit nur einer Staatsangeh.
replace sa2=.     if ef368==8 & ef370==0
replace sadopp=1  if ef368==8 & ef370!=0
/* deaktiviert: replace sa2=ef370 if ef368==8 & ef370!=0  */
label def ausl    0 "[0] nein" 1 "[1] ja"
label def sadopp  0 "[0] nein" 1 "[1] ja"
label val ausl ausl 
* Einbuergerung
replace eingeb=1    if ef372==1 
replace jeinb=ef373 if ef372==1
replace jeinb=9     if ef372==1 & ef373==0
replace sa3=ef374   if ef372==1
replace sa3=.       if ef372==1 & ef374==0

* Keine Einbuergerung
replace eingeb=0 if ef372!=1
replace jeinb=9  if ef372!=1
replace sa3=0    if ef372!=1
* A) im Ausland geboren 
* A1) als Auslaender zugewandert
replace mig=41     if brdborn==8 & ausl==1
replace sa=sa1     if brdborn==8 & ausl==1 & mig==41
replace sa_erw=sa1 if brdborn==8 & ausl==1 & mig==41

* A2) Eingebuergerter
replace mig=31     if brdborn==8 & ausl==0 & eingeb==1 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==1 & mig==31
replace sa_erw=sa3 if brdborn==8 & ausl==0 & eingeb==1 & mig==31
replace sa_erw=sa2 if brdborn==8 & ausl==0 & eingeb==1 & mig==31 & sa_erw==.
replace sa_erw=99  if brdborn==8 & ausl==0 & eingeb==1 & mig==31 & sa_erw==.

* A3) Vertriebener vor 1950 
replace mig=11     if brdborn==8 & ausl==0 & eingeb==0 & jzuzug==1949 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==0 & jzuzug==1949 & mig==11
replace sa_erw=sa1 if brdborn==8 & ausl==0 & eingeb==0 & jzuzug==1949 & mig==11
* A4) als Deutscher zugewandert 
replace mig=21     if brdborn==8 & ausl==0 & eingeb==0 & jzuzug>1949 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==0 & jzuzug>1949 & mig==21
replace sa_erw=sa1 if brdborn==8 & ausl==0 & eingeb==0 & jzuzug>1949 & mig==21
replace sa_erw=sa2 if brdborn==8 & ausl==0 & eingeb==0 & jzuzug>1949 & mig==21 & sa2!=.

* ... Zuzugsjahr missing: Zuzug ohne Angabe zum Jahr d.h. kann Vertriebener oder Spaetaussiedler sein
* Annahme 1: wenn nach 1949 geboren, als Spaetaussiedler zugewandert
replace mig=21     if brdborn==8 & ausl==0 & eingeb==0 & gebj>1949 & jzuzug==9 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==0 & gebj>1949 & jzuzug==9 & mig==21
replace sa_erw=sa1 if brdborn==8 & ausl==0 & eingeb==0 & gebj>1949 & jzuzug==9 & mig==21
replace sa_erw=sa2 if brdborn==8 & ausl==0 & eingeb==0 & gebj>1949 & jzuzug==9 & mig==21 & sa2!=.
* Annahme 2: Wenn vor 1949 geboren und keine auslaendische SA dann Vertriebener 
replace mig=11     if brdborn==8 & ausl==0 & eingeb==0 & sadopp==0 & sa1==0 & jzuzug==9 & gebj<=1949 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==0 & sadopp==0 & sa1==0 & jzuzug==9 & mig==11
replace sa_erw=sa1 if brdborn==8 & ausl==0 & eingeb==0 & sadopp==0 & sa1==0 & jzuzug==9 & mig==11

* Annahme 3: sonst Zuzug als Spaetaussiedler ohne Datumsangabe: 29 
replace mig=29     if brdborn==8 & ausl==0 & eingeb==0 & sadopp==1 & sa1==0 & jzuzug==9 & mig==.
replace sa=sa1     if brdborn==8 & ausl==0 & eingeb==0 & sadopp==1 & sa1==0 & jzuzug==9 & mig==29
replace sa_erw=sa1 if brdborn==8 & ausl==0 & eingeb==0 & sadopp==1 & sa1==0 & jzuzug==9 & mig==29
replace sa_erw=sa2 if brdborn==8 & ausl==0 & eingeb==0 & sadopp==1 & sa1==0 & jzuzug==9 & mig==29 & sa2!=.

* B) im Inland geboren: 
* B1) als Auslaender in D geboren 
replace mig=42     if brdborn==1 & ausl==1 & mig==.
replace sa=sa1     if brdborn==1 & ausl==1 & mig==42
replace sa_erw=sa1 if brdborn==1 & ausl==1 & mig==42

* B2) Eingebuergerter, in Deutschland geboren
replace mig=32     if brdborn==1 & ausl==0 & eingeb==1 & mig==.
replace sa=sa1     if brdborn==1 & ausl==0 & eingeb==1 & mig==32
replace sa_erw=sa3 if brdborn==1 & ausl==0 & eingeb==1 & mig==32
replace sa_erw=sa2 if brdborn==1 & ausl==0 & eingeb==1 & mig==32 & sa_erw==.
replace sa_erw=99  if brdborn==1 & ausl==0 & eingeb==1 & mig==32 & sa_erw==.

* B3) in Deutschland geborener Deutscher 
replace mig=77     if brdborn==1 & ausl==0 & eingeb==0 & mig==.
replace sa=sa1     if brdborn==1 & ausl==0 & eingeb==0 & mig==77
replace sa_erw=sa3 if brdborn==1 & ausl==0 & eingeb==0 & mig==77 & sa3!=.


rename mig mig1 
label var mig1 "Migrationsstatus Grundtypisierung"
format mig1 %2.0f


* 2005 keine Plausibilisierung zum Spaetaussiedlerstatus MIG=31.


/* *******************************************************************
1a Typisierung des Migrationshintergrundes nicht im Haushalt lebender 
   Eltern
   Angaben zu den nicht im Haushalt lebenden Eltern
   Nomenklatur wie oben mit Suffix
     VE (Vater extern)
     ME (Mutter extern)
******************************************************************** */

* Vorbelegung: keine Angaben zu Vater im Haushalt
gen isve=0
gen sa1ve=0
gen sa2ve=.

* Vater lebt nicht im Haushalt (EF357=8) 
replace isve=1        if (ef357==8)
gen zuzugve=ef358     if (ef357==8)
replace zuzugve=0     if (ef357==8 & ef358==8)
gen jzuzugve=ef359    if (ef357==8)
recode  jzuzugve (0 9999=9) if (ef357==8), copyrest

* nur deutsche SA 
gen auslve=0        if (ef357==8 & ef360==1)
gen sadoppve=0      if (ef357==8 & ef360==1)
replace sa1ve=0     if (ef357==8 & ef360==1)

* deutsche und auslaendische SA 
replace auslve=0    if (ef357==8 & ef360==2)
replace sadoppve=1  if (ef357==8 & ef360==2)
replace sa1ve=0     if (ef357==8 & ef360==2)
replace sa2ve=ef361 if (ef357==8 & ef360==2)

* nur auslaendische SA oder SAs 
replace auslve=1    if (ef357==8 & ef360==8)
replace sa1ve=ef361 if (ef357==8 & ef360==8)
replace sadoppve=0  if (ef357==8 & ef360==8 & ef362==0)
replace sa2ve=.     if (ef357==8 & ef360==8 & ef362==0)
replace sadoppve=1  if (ef357==8 & ef360==8 & ef362!=0)
*   Deaktiviert: if (...) (ef362!=0) sa2ve=ef362

* 'entfaellt' Auspraegung (EF360=0)
replace auslve=0    if (ef357==8 & ef360==0)
replace sadoppve=0  if (ef357==8 & ef360==0)
replace sa1ve=0     if (ef357==8 & ef360==0)
replace sa2ve=.     if (ef357==8 & ef360==0)

* wenn eingebuergert ... 
gen eingebve=1        if (ef357==8 & ef363==1)
gen jeinbve=ef364     if (ef357==8 & ef363==1) // Einbuergerungsjahr
recode jeinbve (0 9999=9), copyrest
gen sa3ve=ef365       if (ef357==8 & ef363==1)
recode  sa3ve (0=.), copyrest

* nicht eingebuergert
replace eingebve=0    if (ef357==8 & ef363!=1)
replace jeinbve=9     if (ef357==8 & ef363!=1)
replace sa3ve=0       if (ef357==8 & ef363!=1)

* A)  wenn Vater zugezogen
* A1) Auslaender, im Ausland geboren
gen migve = 41     if (ef357==8 & zuzugve==1 & auslve==1)
gen save=sa1ve     if (ef357==8 & zuzugve==1 & auslve==1 & migve==41)
gen sa_erwve=sa1ve if (ef357==8 & zuzugve==1 & auslve==1 & migve==41)

* A2) Eingebuergerte/r, im Ausland geboren
replace migve=31       if (ef357==8 & zuzugve==1 & auslve==0 & eingebve==1)
replace save=sa1ve     if (ef357==8 & zuzugve==1 & auslve==0 & eingebve==1 & migve==31)
replace sa_erwve=sa3ve if (ef357==8 & zuzugve==1 & auslve==0 & eingebve==1 & migve==31)       // SA_erw: SA vor Einbuergerung
replace sa_erwve=sa2ve if (ef357==8 & zuzugve==1 & auslve==0 & eingebve==1 & migve==31 & sa3ve==.)    // wenn fehlt, 2. SA
replace sa_erwve=99    if (ef357==8 & auslve==0 & eingebve==1 & migve==31 & sa_erwve==.) // ansonsten 'missing'
* ... wenn Deutscher

* A3) als Deutscher zugewandert
replace migve=21       if (ef357==8 & zuzugve==1 & auslve==0 & eingebve==0 & jzuzugve>=1950)
replace save=sa1ve     if (ef357==8 & zuzugve==1 & auslve==0 & eingebve==0 & jzuzugve>=1950 & migve==21)
replace sa_erwve=sa1ve if (ef357==8 & auslve==0 & eingebve==0 & jzuzugve>=1950 & migve==21) // SA_erw: SA1, ggf. SA2
replace sa_erwve=sa2ve if (ef357==8 & auslve==0 & eingebve==0 & jzuzugve>=1950 & migve==21 & sa2ve!=.)
replace migve=29       if (ef357==8 & zuzugve==1 & auslve==0 & eingebve==0 & jzuzugve==9)
replace save=sa1ve     if (ef357==8 & zuzugve==1 & auslve==0 & eingebve==0 & jzuzugve==9 & migve==29)
replace sa_erwve=sa1ve if (ef357==8 & zuzugve==1 & auslve==0 & eingebve==0 & jzuzugve==9 & migve==29)
replace sa_erwve=sa2ve if (ef357==8 & zuzugve==1 & auslve==0 & eingebve==0 & jzuzugve==9 & migve==29 & sa2ve!=.)


* B) wenn Vater nicht zugezogen, liegen keine Angaben zu Migration vor
* B1) als Auslaender in D geboren
replace migve=77       if (ef357==8 & zuzugve==0) // uneindeutig: im Ausland verblieben oder lebte bereits hier
replace sa1ve=0        if (ef357==8 & zuzugve==0 & migve==77)
replace save=sa1ve     if (ef357==8 & zuzugve==0 & migve==77)
replace sa_erwve=0     if (ef357==8 & zuzugve==0 & migve==77)
replace sa_erwve=sa3ve if (ef357==8 & zuzugve==0 & migve==77 & sa3ve!=.)
label var isve     "Vater (extern: VE): lebt nicht im Haushalt"
label var zuzugve  "Vater extern: Zuzug"
label def zuzugve   0 "kein Zuzug" 1 "nach 1960 zugezogen=foreign born" 9 "k.A."
label var jzuzugve "Vater extern: zuzugsjahr"
label def jzuzugve  0 "entfaellt ef359=0"  9 "k.A. zum zuzugsjahr"
label val jzuzugve jzuzugve
*                     1960-2005: jeweiliges jahr
label var auslve   "Vater extern: Auslaendische Staatsangehoerigkeit"
label def auslve  0 "nein" 1 "ja"
label val auslve auslve 
label var sadoppve "Vater extern: Doppelte Staatsangehoerigkeit"
label def sadoppve 0 "nein" 1 "ja"
label val sadoppve sadoppve
label var save     "Vater extern: Aktuelle Staatsangehoerigkeit"
label var sa1ve    "Vater extern: Aktuelle (1.) Staatsangehoerigkeit"
label var sa2ve    "Vater extern: Aktuelle (2.) Staatsangehoerigkeit"
label var sa3ve    "Vater extern: Staatsangehoerigkeit vor Einbuergerung"
label var sa_erwve "Vater extern: Erweiterte akt. Staatsangehoerigkeit"
label var eingebve "Vater extern: Einbuergerung"
label def eingebve 0 "nein" 1 "ja"
label val eingebv eingebve
label var jeinbve  "Vater extern: Einbuergerungsjahr"
label var migve    "Vater extern: Migrationsstatus"
/* label def migve 11 "Vertriebene vor 1950" ///
                21 "Deutsche Zuwanderer"
                29 "Als Deutscher zugewandert o.a. zum Zuzugsjahr"
                31 "Zugewanderte/r eingebuergerte/r Auslaender/in"
                32 "Nicht zugewanderte/r eingebuergerte/r Auslaender/in"
                41 "Zugewanderte/r Auslaender/in"
                42 "Nicht zugewanderte/r Auslaender/in"
                77 "uneindeutig ob deutsch, vertrieben oder deutscher Zuwanderer"
                99 "fehlende/unvollstaendige Angaben" 
*/

format zuzugve auslve sadoppve eingebve %1.0f
format sa1ve sa2ve sa3ve sa_erwve migve %2.0f
format jzuzugve jeinbve %4.0f



* --------------------------------------------------------------------
* Angaben zur Mutter
* Vorbelegung: keine Angaben zur Mutter im Haushalt
gen isme=0
gen sa1me=0
gen sa2me=.

* Mutter lebt nicht im Haushalt (EF349=8) 
replace isme=1        if (ef349==8)
gen zuzugme=ef350     if (ef349==8)
replace zuzugme=0     if (ef349==8 & ef350==8)
gen jzuzugme=ef351    if (ef349==8)
recode  jzuzugme (0 9999=9) if (ef349==8), copyrest

* nur deutsche SA 
gen auslme=0        if (ef349==8 & ef352==1) 
gen sadoppme=0      if (ef349==8 & ef352==1)
replace sa1me=0     if (ef349==8 & ef352==1)

* deutsche und auslaendische SA 
replace auslme=0    if (ef349==8 & ef352==2)
replace sadoppme=1  if (ef349==8 & ef352==2)
replace sa1me=0     if (ef349==8 & ef352==2)
replace sa2me=ef353 if (ef349==8 & ef352==2)

* nur auslaendische SA oder SAs 
replace auslme=1    if (ef349==8 & ef352==8)
replace sa1me=ef353 if (ef349==8 & ef352==8)
replace sadoppme=0  if (ef349==8 & ef352==8 & ef354==0)
replace sa2me=.     if (ef349==8 & ef352==8 & ef354==0)
replace sadoppme=1  if (ef349==8 & ef352==8 & ef354!=0)
*   Deaktiviert: if (...) (ef354!=0) sa2me=ef354
* 'entfaellt' Auspraegung (ef352=0)
replace auslme=0    if (ef349==8 & ef352==0)
replace sadoppme=0  if (ef349==8 & ef352==0)
replace sa1me=0     if (ef349==8 & ef352==0)
replace sa2me=.     if (ef349==8 & ef352==0)

* wenn eingebuergert ... 
gen eingebme=1        if (ef349==8 & ef355==1)
gen jeinbme=ef356     if (ef349==8 & ef355==1) // Einbuergerungsjahr
recode jeinbme (0 9999=9), copyrest
gen sa3me=ef382       if (ef349==8 & ef355==1)
recode  sa3me (0=.), copyrest

* nicht eingebuergert
replace eingebme=0    if (ef349==8 & ef355!=1)
replace jeinbme=9     if (ef349==8 & ef355!=1)
replace sa3me=0       if (ef349==8 & ef355!=1)

* A)  wenn Mutter zugezogen
* A1) Auslaenderin, im Ausland geboren
gen migme = 41     if (ef349==8 & zuzugme==1 & auslme==1)
gen same=sa1me     if (ef349==8 & zuzugme==1 & auslme==1 & migme==41)
gen sa_erwme=sa1me if (ef349==8 & zuzugme==1 & auslme==1 & migme==41)

* A2) Eingebuergerte/r, im Ausland geboren
replace migme=31       if (ef349==8 & zuzugme==1 & auslme==0 & eingebme==1)
replace same=sa1me     if (ef349==8 & zuzugme==1 & auslme==0 & eingebme==1 & migme==31)
replace sa_erwme=sa3me if (ef349==8 & zuzugme==1 & auslme==0 & eingebme==1 & migme==31)       // SA_erw: SA vor Einbuergerung
replace sa_erwme=sa2me if (ef349==8 & zuzugme==1 & auslme==0 & eingebme==1 & migme==31 & sa3me==.)    // wenn fehlt, 2. SA
replace sa_erwme=99    if (ef349==8 & auslme==0 & eingebme==1 & migme==31 & sa_erwme==.) // ansonsten 'missing'
* ... wenn Deutsche

* A3) als Deutsche zugewandert
replace migme=21       if (ef349==8 & zuzugme==1 & auslme==0 & eingebme==0 & jzuzugme>=1950)
replace same=sa1me     if (ef349==8 & zuzugme==1 & auslme==0 & eingebme==0 & jzuzugme>=1950 & migme==21)
replace sa_erwme=sa1me if (ef349==8 & auslme==0 & eingebme==0 & jzuzugme>=1950 & migme==21) // SA_erw: SA1, ggf. SA2
replace sa_erwme=sa2me if (ef349==8 & auslme==0 & eingebme==0 & jzuzugme>=1950 & migme==21 & sa2me!=.)
replace migme=29       if (ef349==8 & zuzugme==1 & auslme==0 & eingebme==0 & jzuzugme==9)
replace same=sa1me     if (ef349==8 & zuzugme==1 & auslme==0 & eingebme==0 & jzuzugme==9 & migme==29)
replace sa_erwme=sa1me if (ef349==8 & zuzugme==1 & auslme==0 & eingebme==0 & jzuzugme==9 & migme==29)
replace sa_erwme=sa2me if (ef349==8 & zuzugme==1 & auslme==0 & eingebme==0 & jzuzugme==9 & migme==29 & sa2me!=.)

* B) wenn Mutter nicht zugezogen, liegen keine Angaben zu Migration vor
* B1) als Auslaenderin in D geboren
replace migme=77       if (ef349==8 & zuzugme==0) // uneindeutig: im Ausland verblieben oder lebte bereits hier
replace sa1me=0        if (ef349==8 & zuzugme==0 & migme==77)
replace same=sa1me     if (ef349==8 & zuzugme==0 & migme==77)
replace sa_erwme=0     if (ef349==8 & zuzugme==0 & migme==77)
replace sa_erwme=sa3me if (ef349==8 & zuzugme==0 & migme==77 & sa3me!=.)

label var isme     "Mutter (extern: ME): lebt nicht im Haushalt"
label var zuzugme  "Mutter extern: Zuzug"
label def zuzugme   0 "kein Zuzug" 1 "nach 1960 zugezogen=foreign born" 9 "k.A."
label var jzuzugme "Mutter extern: zuzugsjahr"
label def jzuzugme  0 "entfaellt ef351=0"  9 "k.A. zum zuzugsjahr"
label val jzuzugme jzuzugme
*                     1960-2005: jeweiliges jahr
label var auslme   "Mutter extern: Auslaendische Staatsangehoerigkeit"
label def auslme  0 "nein" 1 "ja"
label val auslme auslme 
label var sadoppme "Mutter extern: Doppelte Staatsangehoerigkeit"
label def sadoppme 0 "nein" 1 "ja"
label val sadoppme sadoppme
label var same     "Mutter extern: Aktuelle Staatsangehoerigkeit"
label var sa1me    "Mutter extern: Aktuelle (1.) Staatsangehoerigkeit"
label var sa2me    "Mutter extern: Aktuelle (2.) Staatsangehoerigkeit"
label var sa3me    "Mutter extern: Staatsangehoerigkeit vor Einbuergerung"
label var sa_erwme "Mutter extern: Erweiterte akt. Staatsangehoerigkeit"
label var eingebme "Mutter extern: Einbuergerung"
label def eingebme 0 "nein" 1 "ja"
label val eingebv eingebme
label var jeinbme  "Mutter extern: Einbuergerungsjahr"
label var migme    "Mutter extern: Migrationsstatus"
/* label def migme 11 "Vertriebene vor 1950" ///
                21 "Deutsche Zuwanderer"
                29 "Als Deutscher zugewandert o.a. zum Zuzugsjahr"
                31 "Zugewanderte/r eingebuergerte/r Auslaender/in"
                32 "Nicht zugewanderte/r eingebuergerte/r Auslaender/in"
                41 "Zugewanderte/r Auslaender/in"
                42 "Nicht zugewanderte/r Auslaender/in"
                77 "uneindeutig ob deutsch, vertrieben oder deutscher Zuwanderer"
                99 "fehlende/unvollstaendige Angaben" 
*/
format zuzugme auslme sadoppme eingebme %1.0f
format sa1me sa2me sa3me sa_erwme migme %2.0f
format jzuzugme jeinbme %4.0f

* Ausgangssortierung
sort ef1 ef3 ef4 ef12 ef5
* Zwischenspeicherung Grundtypisierung 
sort ef1 ef3 ef4 ef12 ef5
save temp_mig1.dta, replace


/* ============================================================================
2. Identifikation von 3-Generationen-Haushalten

   Fuer die nachfolgende Typisierung des Migrationshintergrundes von Eltern 
   unter Verwendung von Angaben der Grosseltern werden in diesem Schritt 
   3-Generationen-Haushalte identifiziert und Identifikatoren fuer Eltern und 
   rosseltern gebildet. */

* --- ELTERN: VATER, MUTTER --- 
* VATER 
*    EF54 Vater im Haushalt: fuer Ledige: 1=ja 8=nein 0=entf
*    EF55 Nr. des Vaters im Haushalt 
gen vnr = ef55 if (ef54==1)
label var vnr "Personennr. des Vaters (EF55)"

* ZWISCHENSPEICHERUNG GESAMTFILE
save temp.dta, replace

preserve
keep if ef54==1
keep ef1 ef3 ef4 ef12 vnr

* ==> Sortierung ... vnr
sort ef1 ef3 ef4 ef12 vnr
rename vnr ef5

gen v_kids=1
collapse (count) v_kids, by(ef1 ef3 ef4 ef12 ef5)
label var v_kids "Anzahl lediger Kinder eines Vaters"

save temp_V1.dta, replace
restore 

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 ef4 ef12 ef5

* Anzahl der Kinder den Vaetern zuspielen 
merge m:m ef1 ef3 ef4 ef12 ef5 using temp_V1.dta
* tab v_kids _merge, miss nolab
keep if _merge!=2 // Ausschluss von Faellen fehlender Vaeter in den Daten
drop _merge
recode v_kids (1/99=1), gen(vater)
label var vater "Vater lediger Kinder im HH"

* MUTTER
*    EF52 Mutter im Haushalt: fuer Ledige: 1=ja 8=nein 0=entf
*    EF53 Nr. der Mutter im Haushalt
* MUTTER: ef52 Mutter im Haushalt: fuer Ledige: 1=ja 8=nein 0=entf
*         ef53 Nr. der Mutter im Haushalt 
gen mnr = ef53 if (ef52==1)
label var mnr "Personennr. der Mutter (EF53)"

* ZWISCHENSPEICHERUNG GESAMTFILE
* Sortierung des Ausgangsfiles
sort ef1 ef3 ef4 ef12 ef5
save temp.dta, replace

preserve
keep if ef52==1
keep ef1 ef3 ef4 ef12 mnr

* ==> Sortierung ... mnr
sort ef1 ef3 ef4 ef12 mnr
rename mnr ef5

gen m_kids=1
collapse (count) m_kids, by(ef1 ef3 ef4 ef12 ef5)
label var m_kids "Anzahl lediger Kinder einer Mutter"
save temp_M1.dta, replace
restore

* GESAMTFILE 
use temp.dta, clear
sort ef1 ef3 ef4 ef12 ef5

* Anzahl der Kinder den Muettern zuspielen 
merge m:m ef1 ef3 ef4 ef12 ef5 using temp_M1.dta
* tab _merge ef52, miss
keep if _merge!=2 // Ausschluss von Faellen fehlender Muetter in den Daten
drop _merge
recode m_kids (1/99=1), gen(mutter)
label var mutter "Mutter lediger Kinder im HH"

* ZWISCHENSPEICHERUNG GESAMTFILE
* Sortierung des Ausgangsfiles
sort ef1 ef3 ef4 ef12 ef5
save temp.dta, replace


* GROSSELTERN
* Eltern (Mutter oder Vater) mit Angaben zur (Gross-)Mutter:
*   Personennummer der Grossmutter
generate gmnr = ( (mutter==1 | vater==1) & ef52==1) * ef53
* Eltern (Mutter oder Vater) mit Angaben zum (Gross-)Vater: 

*   Personennummer des Grossvaters 
generate gvnr = ( (mutter==1 | vater==1) & ef54==1) * ef55

egen min_gmnr = min(gmnr * (gmnr>0)), by(ef1 ef3 ef4 ef12)
egen max_gmnr = max(gmnr * (gmnr>0)), by(ef1 ef3 ef4 ef12)
egen min_gvnr = min(gvnr * (gvnr>0)), by(ef1 ef3 ef4 ef12)
egen max_gvnr = max(gvnr * (gvnr>0)), by(ef1 ef3 ef4 ef12)


* Grossvater-/mutter
gen gmutter = (max_gmnr==ef5) if max_gmnr>0
gen gvater  = (max_gvnr==ef5) if max_gvnr>0

* ZWISCHENSPEICHERUNG GESAMTFILE
* Sortierung des Ausgangsfiles
sort ef1 ef3 ef4 ef12 ef5
save temp.dta, replace

/* ====================================================================
 3. Endtypisierung der Grosseltern

    Angaben zu den im Haushalt lebenden Eltern
    Vater:    migv  sa1v  sa2v  sa3v  sav  sa_erwv
    Mutter:   migm  sa1m  sa2m  sa3m  sam  sa_erwm

* ------- ZUNAECHST NUR DIE IM HAUSHALT LEBENDEN GROSSELTERN ------- */

* Sichern des Migrationsstatus vor Endtypisierung Grosseltern
gen mig2a = mig1
label var mig2a "Migrationsstatus nach Grundtypisierung - vor Endtypisierung Grosseltern"
format mig2a %2.0f

* Bei Grosseltern liegen nur externe Angaben (*VE, *ME) vor
for var migve sa1ve sa2ve sa3ve save sa_erwve /// X
  \ new migv  sa1v  sa2v  sa3v  sav  sa_erwv  /// Y
  : gen Y = X if (gvater==1 | gmutter==1)
label var migv "Migrationsstatus Vater - vorl. nur fuer Grosseltern"
format migv %2.0f

for var migme sa1me sa2me sa3me same sa_erwme /// X
  \ new migm  sa1m  sa2m  sa3m  sam  sa_erwm  /// Y
  : gen Y = X if (gvater==1 | gmutter==1)
label var migm "Migrationsstatus Mutter - vorl. nur fuer Grosseltern"
format migm %2.0f
recode mig2a (11 21 29 31 41=.) (*=1) if (gvater==1 | gmutter==1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle - Grosseltern"

* im Inland geborene GROSSELTERN
generate _mig_  = mig2a   if (konvproc==1 & (gvater==1 | gmutter==1))     // MIG-Status Grosseltern vor Konversion
recode migv (.=99) (22 23=21) if (konvproc==1 & (gvater==1 | gmutter==1)), gen(_migv_) copyrest // MIG-Status Vater
recode migm (.=99) (22 23=21) if (konvproc==1 & (gvater==1 | gmutter==1)), gen(_migm_) copyrest // MIG-Status Vater
format _mig_ _migv_ _migm_ %2.0f

* ZWISCHENSPEICHERUNG GESAMTFILE
*    Ausgangssortierung
sort ef1 ef3 ef4 ef12 ef5
save temp.dta, replace

merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched) /* ex: conversion_2011.xls */
* tab _merge, miss
drop _merge

* Neu bilden, falls ggf. durch merge ueberschrieben
drop konvproc
recode mig2a (11 21 29 31 41=.) (*=1) if (gvater==1 | gmutter==1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle - Grosseltern"

* Ausgangssortierung
sort ef1 ef3 ef4 ef12 ef5

* Uebernahme konvertierter MIG-Typisierung
gen mig2 = mig2a
replace mig2 = migneu if (konvproc==1 & migneu!=.)
format mig2 %2.0f
label var mig2 "Migrationsstatus nach Endtypisierung Grosseltern"

/* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag 
          ergaenzen, sofern noetig und moeglich 
          Nur im Inland geborene Grosseltern */
replace sa_erw = sa_erwv if (konvproc==1 & (gvater==1 | gmutter==1) &  ///
                             (sa_erw==0 | sa_erw==99) & ///
                             (sa_erwv>0 & sa_erwv<99) )
replace sa_erw = sa_erwm if (konvproc==1 & (gvater==1 | gmutter==1) &  ///
                            (sa_erw==0 | sa_erw==99) & ///
                            (sa_erwm>0 & sa_erwm<99) )

* Variablen aus Datei conversion.dta loeschen
drop _mig_ _migv_ _migm_ konvproc migneu kennung 

* ZWISCHENSPEICHERUNG GESAMTFILE NACH ENDTYPISIERUNG GROSSELTERN
* Ausgangssortierung
sort ef1 ef3 ef4 ef12 ef5
save temp_1.dta, replace


/* ====================================================================
  4. Endtypisierung der Eltern

     Fuer jede Kombination von eigenem, vaeterlichen und muetterlichen 
     vorlaeufigen Migrationsstatus wird der resultierende endgueltige 
     Migrationsstatus zugewiesen. Diese Konversions-Prozedur wird nur fuer 
     im Inland Geborene angewandt.
     Abschliessend wird die Variable erweiterte Staatsangehoerigkeit (SA_erw)
     ggf. durch Informationen zum Vater bzw. zur Mutter ergaenzt. */

/* ===== ANGABEN ZU DEM IM HAUSHALT LEBENDEN GROSSVATER ====*/
egen mig_gv    = max(mig2*(gvater==1)), by(ef1 ef3 ef4 ef12)
egen sa1_gv    = max(sa1*(gvater==1)), by(ef1 ef3 ef4 ef12)
egen sa2_gv    = max(sa2*(gvater==1)), by(ef1 ef3 ef4 ef12)
egen sa3_gv    = max(sa3*(gvater==1)), by(ef1 ef3 ef4 ef12)
egen sa_gv     = max(sa*(gvater==1)),  by(ef1 ef3 ef4 ef12)
egen sa_erw_gv = max(sa_erw*(gvater==1)), by(ef1 ef3 ef4 ef12)

* Angaben zum Status des Grossvaters nur falls der Grossvater 
*    der Vater ist, sonst SYSMIS
recode mig_gv sa1_gv sa2_gv sa3_gv sa_gv sa_erw_gv (nonmiss=.) if gvnr!=ef55
egen mig_gm    = max(mig2*(gmutter==1)), by(ef1 ef3 ef4 ef12)
egen sa1_gm    = max(sa1*(gmutter==1)), by(ef1 ef3 ef4 ef12)
egen sa2_gm    = max(sa2*(gmutter==1)), by(ef1 ef3 ef4 ef12)
egen sa3_gm    = max(sa3*(gmutter==1)), by(ef1 ef3 ef4 ef12)
egen sa_gm     = max(sa*(gmutter==1)),  by(ef1 ef3 ef4 ef12)
egen sa_erw_gm = max(sa_erw*(gmutter==1)), by(ef1 ef3 ef4 ef12)

* Angaben zum Status der Grossmutter nur falls die Grossmutter
*   die Mutter ist, sonst SYSMIS.
recode mig_gm sa1_gm sa2_gm sa3_gm sa_gm sa_erw_gm (nonmiss=.) if gmnr!=ef53


/* --------------------------------------------------------------------
Ab hier die eigentliche Endtypisierung des Migrationsstatus der Eltern 
mittels Konversions-Prozedur, bei der nur im Inland Geborene 
beruecksichtigt werden. */

recode mig2 (11 21 22 23 25 29 31 41=.) (*=1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle"

* EGRE: Eltern - Grosseltern .
gen egre = 1 if ( (vater==1  & (gvnr==ef55)) | /// Vater mit Grossvater 
                  (vater==1  & (gmnr==ef53)) | /// Vater mit Grossmutter
                  (mutter==1 & (gvnr==ef55)) | /// Mutter mit Grossvater
                  (mutter==1 & (gmnr==ef53)))  //  Mutter mit Grossmutter 
label var egre "Eltern mit Grosseltern im Haushalt"
format konvproc egre %1.0f


* Typisierung Eltern-Grosseltern
gen egretyp=0
replace egretyp = 1 if (vater==1  & gvnr==ef55)              // Vater mit Grossvater
replace egretyp = 2 if (vater==1  & gmnr==ef53)              // Vater mit Grossmutter
replace egretyp = 3 if (vater==1  & gvnr==ef55 & gmnr==ef53) // Vater mit Grossvater und -mutter
replace egretyp = 4 if (mutter==1 & gvnr==ef55)  // Mutter mit Grossvater
replace egretyp = 5 if (mutter==1 & gmnr==ef53)  // Mutter mit Grossmutter
replace egretyp = 6 if (mutter==1 & gvnr==ef55 & gmnr==ef53)  // Mutter mit Grossvater und -mutter
label var egretyp "Eltern mit Grosseltern im Haushalt"
label def egretyp 1 "[1] Vater mit Grossvater"   2 "[2] Vater mit Grossmutter" ///
                  3 "[3] Vater mit Grosseltern"  4 "[4] Mutter mit Grossvater" ///
                  5 "[5] Mutter mit Grossmutter" 6 "[6] Mutter mit Grosseltern" ///
                  0 "[0] TNZ"
label val egretyp egretyp
format egretyp %1.0f

* Vorbereitung MATCH Konversionstabelle
* Nur im Inland geborene Eltern, die nicht Grosseltern sind (EGRETYP=1-6)
*    Migrationsstatus
generate _mig_  = mig2   if (konvproc==1 & (vater==1 | mutter==1))    // MIG-Status Eltern vor Konversion
generate _migv_ = migve  if (konvproc==1 & (vater==1 | mutter==1) & isve==1) // Vater lebt nicht im HH
generate _migm_ = migme  if (konvproc==1 & (vater==1 | mutter==1) & isme==1) // Mutter lebt nicht im HH
replace  _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1) & egretyp==1)  // Vater mit Grossvater im HH
replace  _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1) & egretyp==2)  // Vater mit Grossmutter
replace  _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1) & egretyp==3)  // Vater mit Grossvater und -mutter
replace  _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1) & egretyp==3)  // Vater mit Grossvater und -mutter
replace  _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1) & egretyp==4)  // Mutter mit Grossvater
replace  _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1) & egretyp==5)  // Mutter mit Grossmutter
replace  _migv_ = mig_gv if (konvproc==1 & (vater==1 | mutter==1) & egretyp==6)  // Mutter mit Grossvater und -mutter
replace  _migm_ = mig_gm if (konvproc==1 & (vater==1 | mutter==1) & egretyp==6)  // Mutter mit Grossvater und -mutter
replace  _migm_ = 99 if (konvproc==1 & (vater==1 | mutter==1) & _migm_==.)
replace  _migv_ = 99 if (konvproc==1 & (vater==1 | mutter==1) & _migv_==.)
format _mig_ _migv_ _migm_ %2.0f

*    Staatsangehoerigkeit erweitert (SA_erw) der Eltern (die nicht Grosseltern sind)
*      Ergaenzung um Angaben zu den nicht im Haushalt lebenden Eltern
replace sa_erw_gv = sa_erwve if (konvproc==1 & (vater==1 | mutter==1) & isve==1 & /// Vater lebt nicht im HH
                                 (egretyp==0 | egretyp==2 | egretyp==5))
replace sa_erw_gm = sa_erwme if (konvproc==1 & (vater==1 | mutter==1) & isme==1 & /// Mutter lebt nicht im HH
                                 (egretyp==0 | egretyp==1 | egretyp==4))

* ZWISCHENSPEICHERUNG GESAMTFILE
*    Ausgangssortierung
sort ef1 ef3 ef4 ef12 ef5
save temp.dta, replace

merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
* tab _merge, miss
drop _merge

* Ausgangssortierung
sort ef1 ef3 ef4 ef5

* Uebernahme konvertierter MIG-Typisierung
gen mig3 = mig2
replace mig3 = migneu if (egre==1 & konvproc==1 & migneu!=.)
format mig3 %2.0f

label var mig3 "Migrationsstatus nach Endtypisierung Eltern"
/* label def mig3 ///
    0 "[0] nicht zuordenbar (Rest)" ///
   11 "[11] Vertriebene vor 1950" ///
   21 "[21] Deutsche Zuwanderer oder (Spaet-)Aussiedler (ohne Einbuergerung)" ///
   22 "[22] Ehegatte oder Kind eines (Spaet-)Aussiedlers (mit/ohne Einbuergerung)" ///
   25 "[25] (Spaet-)Aussiedler (mit Einbuergerung)" ///
   29 "[29] (Spaet-)Aussiedler (mit/ohne Einbuergerung) o.A. zum Zuzugsjahr" ///
   31 "[31] zugewanderte/r eingebuergerte/r Auslaender/in" ///
   32 "[32] nicht zugewanderte/r eingebuergerte/r Auslaender/in" ///
   41 "[41] zugewanderte/r Auslaender/in" ///
   42 "[42] nicht zugewanderte/r Auslaender/in" ///
   43 "[43] nicht zugewanderte/r Auslaender/in, beide Eltern hier geboren" ///
   52 "[52] Deutscher mit einseitigem Migrationshintergrund" ///
   53 "[53] Deutscher mit einseitigem Migrationshintergrund" ///
   54 "[54] Deutscher mit einseitigem Migrationshintergrund" ///
   62 "[62] Deutscher mit zweiseitigem Migrationshintergrund" ///
   63 "[63] Deutscher mit zweiseitigem Migrationshintergrund" ///
   64 "[64] Deutscher mit zweiseitigem Migrationshintergrund" ///
   77 "[77] uneindeutig ob deutsch, vertrieben oder Spaetaussiedler" ///
   99 "[99] fehlende/unvollstaendige Angaben"
label val mig3 mig3 */
* tab mig3, miss

/* SA_erw durch aussagekraeftigen Vater- bzw. Muttereintrag ergaenzen, sofern 
        noetig und moeglich
        Nur im Inland geborene Eltern (ohne Grosseltern) */
replace sa_erw = sa_erw_gv if (konvproc==1 & ((vater==1  & (gvater==0  | gvater==.) ) |   ///
                                              (mutter==1 & (gmutter==0 | gmutter==.)) ) & ///
                              ( (sa_erw==0 | sa_erw==99) & (sa_erw_gv>0 & sa_erw_gv<99) ) )
replace sa_erw = sa_erw_gm if (konvproc==1 & ((vater==1  & (gvater==0  | gvater==.) ) |   ///
                                              (mutter==1 & (gmutter==0 | gmutter==.)) ) & ///
                            ( (sa_erw==0 | sa_erw==99) & (sa_erw_gm>0 & sa_erw_gm<99) ) )

* Konversionsangaben loeschen
drop migneu _mig_ _migv_ _migm_ kennung konvproc

* Zwischenspeicherung Gesamtfile Grundtypisierung + Endtypisierung Eltern
*    Ausgangssortierung
sort ef1 ef3 ef4 ef12 ef5
save temp_mig3.dta, replace 


/* ====================================================================
   5. Endtypisierung Befragte
   
      Analog zur Endtypisierung der Eltern wird der endgueltige
      Migrationsstatus unter Beruecksichtigung der Kombinationen
      von eigenem, vaeterlichen und muetterlichen vorlaeufigen
      Migrationsstatus zugewiesen, wobei auch hier die Zuweisungen
      nur fuer die im Inland Geborenen zur Anwendung kommen, und
      die erweiterte Staatsangehoerigkeit (SA_erw) ggf. durch
      Angaben des Vaters bzw. der Mutter ergaenzt wird.
      Die Variable SA_erw ist Basis der Staatsangehoerigkeit zum
      Migrationsstatus (MIGS). */


* UMBENENNEN der oben gebildeten Variablen, die sonst ueberschrieben werden

* === ZUNAECHST ANGABEN DER IM HAUSHALT LEBENDEN ELTERN  ===

* Migrationsrelevante Eintraege fuer Eltern: mig3 sa1 sa2 sa3 sa sa_erw jzuzug
* vnr = Personennr. des Vaters (EF55)
keep if (vater==1)
keep  ef1 ef3 ef4 ef12 ef5 mig3 sa1 sa2 sa3 sa sa_erw jzuzug


/* Migrationsrelevante Eintraege fuer Muetter speichern */
rename ef5    vnr
rename mig3   mig_v
rename sa1    sa1_v
rename sa2    sa2_v
rename sa3    sa3_v
rename sa     sa_v
rename sa_erw sa_erw_v
rename jzuzug jzuzug_v

save temp_V2.dta, replace

* GESAMTFILE 
use temp_mig3.dta, clear
sort ef1 ef3 ef4 ef12 vnr
* Angaben des Vaters zuspielen 
merge m:m ef1 ef3 ef4 ef12 vnr using temp_V2.dta

* tab _merge ef54, miss
drop _merge
* tab mig_v vater
* Sortierung des Ausgangsfiles wieder herstellen
sort ef1 ef3 ef4 ef12 ef5
save temp_mig3a.dta, replace

/* Migrationsrelevante Eintraege fuer Muetter speichern */
* mnr = Personennr. der Mutter (EF53)
keep if (mutter==1)
keep  ef1 ef3 ef4 ef12 ef5 mig3 sa1 sa2 sa3 sa sa_erw jzuzug
rename ef5    mnr
rename mig3   mig_m
rename sa1    sa1_m
rename sa2    sa2_m
rename sa3    sa3_m
rename sa     sa_m
rename sa_erw sa_erw_m
rename jzuzug jzuzug_m
save temp_M2.dta, replace

* GESAMTFILE 
use temp_mig3a.dta, clear
sort ef1 ef3 ef4 ef12 mnr

* Angaben der Mutter zuspielen 
merge m:m ef1 ef3 ef4 ef12 mnr using temp_M2.dta
* tab _merge ef52, miss
drop _merge
* tab mig_m mutter

* Sortierung des Ausgangsfiles wieder herstellen
sort ef1 ef3 ef4 ef12 ef5
save temp_mig3b.dta, replace

* Vorher zugespielte Variablen aus conversion.dta loeschen
* drop _mig_ _migv_ _migm_ konvproc migneu kennung   


* Konversions-Prozedur nur fuer im Inland Geborene 
recode mig3 (11 21 22 23 25 29 31 41=.) (*=1), gen(konvproc)
label var konvproc "Konversionsprozedur: gueltige Faelle"

* === BERUECKSICHTIGUNG VON ANGABEN DER NICHT IM HAUSHALT LEBENDEN ELTERN  ===

* Vorbereitung MATCH Konversionstabelle (conversion.dta)

* ANGABEN ZU DEN IM HH LEBENDEN ELTERN (s.o.):
* Zum Vater:  mig_v sa1_v sa2_v sa3_v sa_v sa_erw_v jzuzug_v
* Zur Mutter: mig_m sa1_m sa2_m sa3_m sa_m sa_erw_m jzuzug_m

* Kombination Angaben zu Eltern
* PE: EXTERN
generate pe = (isve==0 & isme==0)    // keine externen Angaben zu den Eltern
replace  pe=2 if (isve==1 & isme==1) // externe Angaben zu beiden Eltern
replace  pe=3 if (isve==1 & isme==0) // externe Angaben nur zum Vater
replace  pe=4 if (isve==0 & isme==1) // externe Angaben nur zur Mutter 
format pe %1.0f
label var pe "Externe Angaben zu den Eltern"
label def pe 1 "keine" 2 "beide" 3 "Vater" 4 "Mutter" 0 "sonst"
label val pe pe

* PI: INTERN
generate pi = (ef55==99 & ef53==99)      // keine internen Angaben zu den Eltern
replace  pi = 2 if (ef55!=99 & ef53!=99) // interne Angaben zu beiden Eltern
replace  pi = 3 if (ef55!=99 & ef53==99) // interne Angaben nur zum Vater 
replace  pi = 4 if (ef55==99 & ef53!=99) // interne Angaben nur zur Mutter 
format pi %1.0f
label var pi "Interne Angaben zu den Eltern"
label def pi 1 "keine"  2 "beide"  3 "Vater"  4 "Mutter" 0 "sonst"
label val pi pi

/* Korrektur PE
Einige Haushalte sind unvollstaendig. Deshalb werden keine Eltern
gefunden werden, obwohl die Zeigervariablen (EF53, EF55) gueltige
Angaben enthalten. */
replace pi = 4 if mig_v==. & mig_m!=.
replace pi = 3 if mig_v!=. & mig_m==.
replace pi = 1 if mig_v==. & mig_m==.

* Angaben Grosseltern loeschen
drop migv sa1v sa2v sa3v  sav 
drop migm sa1m sa2m sa3m  sam 

* SA_erwV und SA_erwM aus Schritt Endtypisierung Eltern sichern
gen sa_erwv1 = sa_erwv
gen sa_erwm1 = sa_erwm
label var sa_erwv1 "Erw. Staatsangeh. Vater - Endtypis. Eltern"
label var sa_erwm1 "Erw. Staatsangeh. Mutter - Endtypis. Eltern"
format sa_erwv1 sa_erwm1 %2.0f

* Initialisierung SA_erwV und SA_erwM
replace sa_erwv=99
replace sa_erwm=99
format sa_erwv sa_erwm %2.0f

* Vater lebt nicht im HH (isve=1 := ef357=8)
gen migv=migve       if (isve==1)
gen sa1v=sa1ve       if (isve==1)
gen sa2v=sa2ve       if (isve==1)
gen sa3v=sa3ve       if (isve==1)
gen jzuzugv=jzuzugve if (isve==1)
gen sav=save         if (isve==1)
replace sa_erwv=sa_erwve if (isve==1)

* Gueltige Angaben zu dem im HH lebenden Vater
replace migv=mig_v        if (mig_v!=.)
replace sa1v=sa1_v        if (mig_v!=.)
replace sa2v=sa2_v        if (mig_v!=.)
replace sa3v=sa3_v        if (mig_v!=.)
replace jzuzugv=jzuzug_v  if (mig_v!=.)
replace sav=sa_v          if (mig_v!=.)
replace sa_erwv=sa_erw_v  if (mig_v!=.)

* Mutter lebt nicht im HH (isme=1 := ef349=8)
gen migm=migme           if (isme==1)
gen sa1m=sa1me           if (isme==1)
gen sa2m=sa2me           if (isme==1)
gen sa3m=sa3me           if (isme==1)
gen mzuzugm=jzuzugme     if (isme==1)
gen sam=same             if (isme==1)
replace sa_erwm=sa_erwme if (isme==1)

* Gueltige Angaben zu der im HH lebenden Mutter
replace migm=mig_m        if (mig_m!=.)
replace sa1m=sa1_m        if (mig_m!=.)
replace sa2m=sa2_m        if (mig_m!=.)
replace sa3m=sa3_m        if (mig_m!=.)
replace jzuzugm=jzuzug_m  if (mig_m!=.)
replace sam=sa_m          if (mig_m!=.)
replace sa_erwm=sa_erw_m  if (mig_m!=.)

* Vorbereitung MATCH Konversionstabelle (conversion.dta)
gen _mig_  = mig3  if (konvproc==1) // MIG-Status vor Konversion, SPSS: mig_k
gen _migv_ = migv  if (konvproc==1) // MIG-Status Vater                 migv_k
gen _migm_ = migm  if (konvproc==1) // MIG-Status Mutter                migm_k
recode _migv_ (0 .=99) (22 23=21) if (konvproc==1)
recode _migm_ (0 .=99) (22 23=21) if (konvproc==1)
format _mig_ _migv_ _migm_ %2.0f

* Sortierung fuer Match mit Konversionsprozedur.
sort _mig_ _migv_ _migm konvproc

merge m:1 _mig_ _migv_ _migm_  using conversion.dta, keep(master matched)
drop _merge

* Ausgangssortierung
sort ef1 ef3 ef4 ef12 ef5

* Uebernahme konvertierter MIG-Typisierung
gen mig4 = migneu if (migneu!=.)
replace mig4 = mig3 if (migneu==.)

label var mig4 "Migrationsstatus nach Endtypisierung Befragte"
format mig4 %2.0f
* tab mig4, miss


* SA_erw durch aussagekraeftigen Vatereintrag und Muttereintrag .
*        ergaenzen, sofern noetig und moeglich .
*    SA_erw zur Kontrolle der Rekodierung als SA_erw0 sichern.
gen sa_erw0 = sa_erw
replace sa_erw=sa_erwv if (konvproc==1) & ( (sa_erw==0 | sa_erw==99) & (sa_erwv>0 & sa_erwv<99) ) 
replace sa_erw=sa_erwm if (konvproc==1) & ( (sa_erw==0 | sa_erw==99) & (sa_erwm>0 & sa_erwm<99) )

* tab sa_erw, miss


* Zwischenspeicherung
save "temp_MIG4.dta", replace


/* Variablen VOR zeitreihenkompatibler Recodierung 
   Migrationsstatus nach Endtypisierung Befragte 
   - aufgrund der Verwendung von Angaben zu Eltern ausserhalb des 
    Haushalts nicht vollstaendig vergleichbar mit 2006-2008, 2010ff. */  
gen mig2005=mig4
* Recodierung wie SUF 2008 und 2009
recode mig2005 (29=21), copyrest
label var mig2005 "Mig-status 2005 - nicht zeitreihenkompatibel"
format mig2005 %2.0f

* Staatsangehoerigkeit zum Migrationsstatus nach Endtypisierung Befrage
gen migs2005=sa_erw
* fuer einheimische Bevoelkerung auf Entfaellt setzen
replace migs2005 = 0 if (mig2005==0 | mig2005==11)
label var migs2005 "Erw. Staatsangeh. zum Mig-status MIG2005 - nicht zeitreihenkompatibel"
format migs2005 %2.0f


/* =====================================================================
   6. Umsetzung der Zeitreihenkompatibilitaet
   
      In den Jahren 2005 und 2009 laesst sich aufgrund der Zusatzangaben
      zum Migrationsstatus der nicht im Haushalt lebenden Eltern der
      Migrationshintergrund von mehr Menschen erkennen als in den anderen
      Jahren. Das schraenkt die Zeitreihenanalyse ein.
      Deshalb wird nachstehend der Migrationsstatus der Menschen in 2005/
      2009 simuliert, der sich ergeben haette, wenn lediglich die Angaben
      aus den anderen Jahren zur Verfuegung gestanden haetten.
      Betroffen sind lediglich die Deutschen mit einseitigem und
      beidseitigem Migrationshintergrund Codes 61 bzw. 62-64
      Es gelten folgende Regeln:
        Einseitiger MigH: Angaben zum bestimmenden Elternteil fehlen:
          Code: 52 -> 72
          Code: 53 -> 73
          Code: 54 -> 74
        Beidseitiger MigH: Angaben zu einem bestimmenden Elternteil fehlen:
          Code: 62 -> 57
          Code: 63 -> 58
          Code: 64 -> 59
        Beidseitiger MigH: Angaben zu beiden bestimmenden Elternteilen fehlen
          Code: 62 -> 77
          Code: 63 -> 78
          Code: 64 -> 79
       (...)
*--------------------------------------------------------------------------------
* ALTERNATIVE RECODIERUNG zu SAS-Originalprogramm
* Zur Umsetzung der zeitreihenkompatiblen MIG - Variable werden
* folgende Variablen verwendet: 
MIG4  Migrationsstatus vor Zeitreihenkompatibilitaet
PI    Interne Angaben zu den Eltern: 1=keine, 2=beide, 3=Vater, 4=Mutter
PE    Externe Angaben zu den Eltern: 1=keine, 2=beide, 3=Vater, 4=Mutter
IsVE  Vater lebt im Haushalt:  0=ja, 1=nein (EF357=8) : Ext. Ang. Vater
IsME  Mutter lebt im Haushalt: 0=ja, 1=nein (EF357=8) : Ext. Ang. Mutter
MIGMI Migrationsstatus Mutter: interne Angaben
MIGVI Migrationsstatus Vater:  interne Angaben 
*/

gen migvi = mig_v // interne Angaben fuer Vater
gen migmi = mig_m // interne Angaben fuer Muetter
format migvi migmi %2.0f

* Hilfsvariablen (SYSMIS => -1)
recode migmi migvi (.=-1), gen(xmigmi xmigvi) copyrest

/* zeitreihenkompatible Recodierung
 Migrationsstatus nach Endtypisierung Befragte
 - aufgrund der Verwendung von Angaben zu Eltern ausserhalb des
 Haushalts nicht vollstaendig vergleichbar mit 2006 - 2008, 20120 ff */
gen mig = mig4
label var mig "Migrationsstatus nach Endtypisierung Befragte - zeitreihenkompatibel"

gen migs = sa_erw
label var migs "Erweiterte Staatsangehoerigkeit zu MIGS [~EF2008~]"
format xmigmi xmigvi mig migs %2.0f

* Fall 1: Beidseitiger MigH der Person (mig4>=62 & mig4<=64)
*         Angaben zu beiden bestimmenden Elternteilen fehlen (PI=1)
replace mig  = mig4 + 15 if ((mig4>=62 & mig4<=64) & (pi==1))
replace migs = 99        if ((mig4>=62 & mig4<=64) & (pi==1))

* Fall 2: Interne Angaben fuer Mutter vorhanden (PI=4)
*         ... dann einseitiger Migrationshintergrund
replace mig  = 58 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=0  & xmigmi<=77))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=0  & xmigmi<=77))
replace mig  = 57 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=21 & xmigmi<=29))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=21 & xmigmi<=29))
replace mig  = 59 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=41 & xmigmi<=43))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==4) & (xmigmi>=41 & xmigmi<=43))

* Fall 3: Interne Angaben fuer Vater vorhanden (PI=3) und 
*         keine internen Angaben fuer Mutter vorhanden 
*         ... dann einseitiger Migrationshintergrund 
replace mig  = 58 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=0  & xmigvi<=77))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=0  & xmigvi<=77))
replace mig  = 57 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=21 & xmigvi<=29))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=21 & xmigvi<=29))
replace mig  = 59 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=41 & xmigvi<=43))
replace migs = 99 if ((mig4>=62 & mig4<=64) & (pi==3) & (xmigvi>=41 & xmigvi<=43))

* Fall 4: Einseitiger Migrationshintergrund (mig4>=52 & mig4<=54)
*         Externe Angaben zum Vater (ISVE=1) ohne
*         interne Angaben zum Vater (EF55!=99) ... dann Code 52-54 -> 72-74
replace mig  = mig4 + 20 if ( (mig4>=52 & mig4<=54) & isve==1 & ef55==99 &  ///
              (migv==21 | migv==22 | migv==23 | migv==25 | migv==29 | migv==31 | ///
              migv==32 | migv==33 | migv==41 | migv==42 | migv==43 | migv==61 | ///
              migv==62 | migv==63 | migv==64) )
replace migs = 99  if ( (mig4>=52 & mig4<=54) & isve==1 & ef55==99 & ///
         (migv==21 | migv==22 | migv==23 | migv==25 | migv==29 | migv==31 | ///
          migv==32 | migv==33 | migv==41 | migv==42 | migv==43 | migv==61 | ///
          migv==62 | migv==63 | migv==64) )

* Fall 5: Einseitiger Migrationshintergrund (mig4>=52 & mig4<=54)
*         Externe Angaben zur Mutter (ISME=1) ohne
*         interne Angaben zur Mutter (EF53!=99)... dann Code 52-54 -> 72-74
replace mig = mig4 + 20 if ( (mig4>=52 & mig4<=54) & isme==1 & ef53==99 & ///
         (migm==21 | migm==22 | migm==23 | migm==25 | migm==29 | migm==31 | ///
          migm==32 | migm==33 | migm==41 | migm==42 | migm==43 | migm==61 | ///
          migm==62 | migm==63 | migm==64) )
replace migs = 99 if ( (mig4>=52 & mig4<=54) & isme==1 & ef53==99 & ///
          (migm==21 | migm==22 | migm==23 | migm==25 | migm==29 | migm==31 | ///
           migm==32 | migm==33 | migm==41 | migm==42 | migm==43 | migm==61 | ///
          migm==62 | migm==63 | migm==64) )

* Recodierung wie SUF 2008 und 2009
recode mig (29=21), copyrest
 
* MIGS (ex SA_erw) fuer einheimische Bevoelkerung auf 0 Entfaellt setzen
replace migs = 0 if (mig==0 | mig==11)
 
label def mig /// Label fuer mig, mig2005, ...
   0 "Deutsch ohne Migrationshintergrund" ///
  11 "Bis einschl. 1949 als Deutscher ohne Einbuergerung zugewandert" ///
  21 "21/29: >=1950 als Deutscher ohne Einbuergerung zugewandert (Spaetaussiedler)(21); Ohne Angabe des Zuzugsjahres als Deutscher ohne Einbuergerung zugewandert(29)" ///
  22 "Ehegatte oder Kind von Spaetaussiedler, zeitgleich eingereist" ///
  25 "Spaetaussiedler mit formaler Einbuergerung" ///
  29 "Ohne Angabe des Zuzugsjahres als Deutscher ohne Einbuergerung zugewandert" ///
  31 "Als Auslaender zugewandert und zwischenzeitlich eingebuergert" ///
  32 "Als Auslaender im Bundesgebiet geboren und zwischenzeitlich eingebuergert" ///
  41 "Als Auslaender auf das heutige Bundesgebiet zuwandert" ///
  42 "Als Auslaender im Bundesgebiet geboren, beide Eltern als Auslaender zugewandert oder ein Elternteil als Auslaender zugewandert, der andere als Auslaender im Bundesgebiet geboren" ///
  43 "Als Auslaender im Bundesgeb. geboren, beide Eltern im Bundesgeb. geboren" ///
  52 "Deutscher mit eins. Mig-hintergrund; Mig-status identifizierbar, weil Eltern im Haushalt; 1 Elternteil Spaetaussiedler (21,22,25,29)" ///
  53 "Deutscher mit eins. Mig-hintergrund; Mig-status identifizierbar, weil Eltern im Haushalt; 1 Elternteil Deutscher durch Einbuerg. (31,32)" ///
  54 "Deutscher mit eins. Mig-hintergrund; Mig-status identifizierbar, weil Eltern im Haushalt; 1 Elternteil ist Auslaender (41,42,43)" ///
  57 "Hier geboren: Deutscher mit beids. Mig-hintergrund; Mig-hintergrund nicht durchweg identifizierbar, weil nur mit 1 Elternteil im Haushalt; dieser Elternteil ist Spaetaussiedler (21,22,25,29)" ///
  58 "Hier geboren: Deutscher mit beids. Mig.hintergrund; Mig-hintergrund nicht durchweg identifizierbar, weil Betroffener nur mit 1 Elternteil im Haushalt; dieser Elternteil ist eingebuergert (31,32)" ///
  59 "Hier geboren: Deutscher mit beids. Mig.hintergrund; Mig-hintergrund nicht durchweg identifizierbar, weil Betroffener nur mit 1 Elternteil im Haushalt; dieser Elternteil ist Auslaender (41,42,43)" ///
  62 "Deutscher mit beids. Mig-hintergrund; Mig-status durchweg identifizierb., weil Eltern im Haushalt lebend; mind. 1 Elternteil ist Spaetaussiedler (21,22,25,29)" ///
  63 "Deutscher mit beids. Mig-hintergrund; Mig-status durchweg identifizierb., weil Eltern im Haushalt; entweder beide Eltern eingeb. (31,32) oder 1 Elternteil eingebuergert (31,32), der andere Auslaender (41,42,43)" ///
  64 "Deutscher mit beids. Mig.hintergrund; Mig-status durchweg identifizierb., weil Eltern im Haushalt; beide Eltern sind Auslaender (41,42,43), es handelt sich um ein ius soli-Kind (Optionsmodell)" ///
  72 "Hier geboren: Deutscher mit eins. Mig-hintergrund; Mig-status nicht durchweg identifizierbar, weil nicht mit jenem Elternteil im Haushalt, der als Spaetaussiedler (21,22,25,29) f. d. Mig-status bestimmend" ///
  73 "Hier geboren: Deutscher mit eins. Mig-hintergrund; Status nicht durchweg identifizierbar, weil nicht mit jenem Elternteil im Haushalt, der als Deutscher durch Einbuergerung (31,32) fuer Status bestimmend ist" ///
  74 "Hier geboren: Deutscher mit eins. Mig-hintergrund; Status nicht durchweg identifizierbar, weil nicht mit jenem Elternteil im Haushalt, der als Auslaender (41,42,43) fuer den Status bestimmend ist" ///
  77 "Hier geboren: Deutscher mit beids. Mig-hintergrund; Status nicht durchweg identifizierbar, weil mit keinem Elternteil im Haushalt; mindestens ein Elternteil ist Spaetaussiedler (21,22,25,29)" ///
  78 "Hier geboren: Deutscher mit beids. Mig.hintergrund; Status nicht durchweg identifizierbar, weil mit keinem Elternteil im Haushalt; entweder beide Eltern eingebuergert (31,32) oder 1 Elternteil eingebuergert (31,32), der andere Auslaender (41,42,43)" ///
  79 "Hier geboren: Deutscher mit beids. Mig-hintergrund; Status nicht durchweg identifizierbar, weil mit keinem Elternteil im Haushalt; beide Eltern sind Auslaender (41,42,43); ius soli-Kind (Optionsmodell)"

label val mig2005 mig
label val mig mig
numlabel mig, add mask("[#] ")  
  
label def migs /// Label fuer ef369 ef374 ef353 ef382 ef361 ef365 sa_erw migs migs2005
    0 "[0] Entfaellt (Deutsche(r) ohne weitere Staatsangehoerigkeit)" ///
    1 "[1] EU-25: PL Polen(23)" ///
    2 "[2] EU-25: SK, CZ, HU: Slowakei (30), Tschechische Republik(33), Ungarn(35)" ///
    3 "[3] EU-25: B, DK, EST, FIN, F,GR, IRL, I, LV, L, M, NL, A, P, S, E, GB, CY" ///
    4 "[4] EU Sonst: RUS: Russische Foederation(26)" ///
    5 "[5] EU Sonst: TR: Tuerkei(34)" ///
    6 "[6] EU Sonst: BG, RO: Bulgarien(03), Rumaenien(25)" ///
    7 "[7] EU Sonst: EU Sonst: BIH,SU, Y, IS, NDH, FL, N, CH, SB, MN" ///
    8 "[8] Afrika: Marokko(40), Sonstiges Nordafrika(41), Sonstiges Afrika(42)" ///
    9 "[9] Amerika, Uebrige Welt, Staatenlos: USA(43), Sonstiges Nordamerika(44), Mittelamerika und Karibik(45), Suedamerika(46), Uebrige Welt(55), Staatenlos(98)" ///
   10 "[10] Naher und Mittlerer Osten: Irak(47), Iran(48), Sonst ... (49)" ///
   11 "[11] Asien: Vietnam(50), Afghanistan(51), Sonst. Sued-/Suedostasien(52), China(53), Sonst. Ostasien(54)" ///
   99 "[99] Unbekannt"  
label val migs migs
label val migs2005 migs
numlabel migs, add mask("[#] ")  
   
   
   
/* ============================================================================
ZU BEACHTEN: MIGS stimmt nicht vollstaendig mit EF2008 ueberein, da die
Codierungen der Angaben zu den Staatsangehoerigkeiten der Eltern ausserhalb
des Haushalts:
- ef353  F105a 1. ausl. Staatsangehoerigk.: Mutter
- EF361  F111a 1. ausl. Staatsangehoerigk.: Vater
von den Angaben zur Person:
- ef369  F99a 1. Staatsangehoerigkeit
abweichen und die Codierungen von ef369 und EF2008 verschieden sind.
============================================================================ */



/* ============================================================================
  7. Variablendefinition fuer SUF- und Fachserien-Ergebnisse

  ===== Recodierungen fuer Vergleiche mit amtlichen Veroeffentlichungen ==== */

* MIGRATIONSSTATUS zeitreihenkompatibel 
* Fachserie 1, Reihe 2.2, Tabelle 2, S. 60.
* Fallzahlen
for var mig migs mig2005 migs2005: table X, row format(%5.0f) miss

* Bevoelkerung am Hauptwohnsitz, Hochrechnung: Jahresdurchschnitt (in 1.000)
gen w952 = ef952/0.7 // Hochrechnungsfaktor EF952, 70%-Substichprobe
for var mig migs mig2005 migs2005 : tab X if (ef30<3) [iw=w952], miss

/* Staatsangehoerigkeit zum Migrationsstatus - zeitreihenkompatibel
* MZ-GRUNDPROGRAMM: Migrationsstatus 
Fachserie 1, Reihe 2.2, Tabelle 2, S. 60
Z___: Zeilennummer in Tab. 2 */
recode mig  (0/79=1) (*=.), gen(Z001)
recode mig  (0 11=1) (*=.), gen(Z002)
recode mig  (21/79=1) (*=.), gen(Z003)
recode mig  (72/79=1) (*=.), gen(Z004)
recode mig  (21/64=1) (*=.), gen(Z005)
recode mig  (21/29 31 41=1) (*=.), gen(Z034)
recode mig  (41=1) (*=.), gen(Z062)
recode mig  (21/29 31=1) (*=.), gen(Z089)
recode mig  (21/29=1) (*=.), gen(Z090)
recode mig  (31=1) (*=.), gen(Z097)
recode mig  (32 42 43 52/64=1) (*=.), gen(Z119)
recode mig  (42 43=1) (*=.), gen(Z126)
recode mig  (32 52/64=1) (*=.), gen(Z133)
recode mig  (32=1) (*=.), gen(Z134)
recode mig  (52/64=1) (*=.), gen(Z140)
recode mig  (62 63 64=1) (*=.), gen(Z141)
recode mig  (52/59=1) (*=.), gen(Z142)
label var Z001 "Bevoelkerung insgesamt (0-79)"
label var Z002 "Personen ohne Mig-hintergrund (0,11)"
label var Z003 "Person mit Mig-hintergrund i. w. S. (21-79)"
label var Z004 "  dar.: Mig-status nicht durchweg bestimmbar (72-79)"
label var Z005 "Personen mit Mig-hintergrund i.e.S. (21-64)"
label var Z034 "Personen mit eigener Mig-erfahrung (21-29,31,41)"
label var Z062 "- Auslaender (41)"
label var Z089 "- Deutsche (21-29,31)"
label var Z090 "  + ohne Einbuergerung (21-29)"
label var Z097 "  + durch Einbuergerung (31)"
label var Z119 "Personen ohne eig. Mig-erf. (32,42,43,52-64)"
label var Z126 "- Auslaender (42-43)"
label var Z133 "- Deutsche (32,52-64)"
label var Z134 "  + durch Einbuergerung (32)"
label var Z140 "  + mit mind 1 zugew. o. als Ausl. in D geb. Elternteil (52-64)"
label var Z141 "    # mit beidseitigem Mig-hintergrund (62-64)"
label var Z142 "    # mit einseitigem Mig-hintergrund (52-59)"
* gen w952=ef952/0.7
summ Z001-Z142 if ef30>=1 & ef30<=2 [iw=w952], sep(0)

/* STAATSANGEHOERIGKEITEN zum Migrationsstatus zeitreihenkompatibel
Deutsche Zuwanderer ohne Einbuergerung sowie in Deutschland geborene Deutsche 
mit ein-/beidseitigem Migrationshintergund => 0 (deutsch)
*/
* Deutsche
recode mig (0 11 21 22 23 25 29 61 62 63 64 71 72 73 74=1), gen(D)
* Z___: Zeilennummer in Tab. 2 
recode migs (1/7=1) (*=.)  if D!=1, gen(Z06)
recode migs (1/3=1) (*=.)  if D!=1, gen(Z07)
recode migs (1=1) (*=.)    if D!=1, gen(Z10)
recode migs (4/7=1) (*=.)  if D!=1, gen(Z11)
recode migs (8=1) (*=.)    if D!=1, gen(Z19)
recode migs (10=1) (*=.)   if D!=1, gen(Z23)
recode migs (0 99=1) (*=.) if D!=1, gen(Z26)
replace Z26=1 if D==1
label var Z06 "Europa"
label var Z07 "- EU-25"
label var Z10 "  + Polen"
label var Z11 "- Sonstiges Europa"
label var Z19 "Afrika"
label var Z23 "-  Naher und Mittlerer Osten"
label var Z26 "Ohne Angabe bzw. unzutreffend"

* Z005 Person mit Migrationshintergrund im engeren Sinn 
summ Z005 Z06-Z26 if ef30>=1 & ef30<=2 & Z005==1 [iw=w952], sep(0)


* Sortierung nach ID_O Satznummer im Ausgangsfile fuer Zuspielen der 
* erstellten Variablen mig, mig2005 und migs* zum Scientific Use File
sort ID_O

* Zwischenspeicherung 
save "temp_mig5.dta", replace
exit

* PROGRAMMENDE 
